Type Definition num_modular::VanillaInt
source · [−]pub type VanillaInt<T> = ReducedInt<T, Vanilla<T>>;Expand description
An integer in modulo ring based on conventional Rem operations
pub type VanillaInt<T> = ReducedInt<T, Vanilla<T>>;An integer in modulo ring based on conventional Rem operations