pub trait DivExact<Rhs, Precompute>: Sized {
type Output;
// Required method
fn div_exact(self, d: Rhs, pre: &Precompute) -> Option<Self::Output>;
}Expand description
Required Associated Types
Required Methods
Sourcefn div_exact(self, d: Rhs, pre: &Precompute) -> Option<Self::Output>
fn div_exact(self, d: Rhs, pre: &Precompute) -> Option<Self::Output>
Check if d divides self with the help of the precomputation. If d divides self, then the quotient is returned.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".